@@ -20,10 +20,9 @@
 #include <gtk/gtk.h>
 #include <glib/gi18n.h>
 #include <libedataserver/e-time-utils.h>
-#include <libedataserver/e-util.h>
+#include <libedataserver/e-data-server-util.h>
 #include <libecal/e-cal-time-util.h>
 #include <e-util/e-icon-factory.h>
-#include <e-util/e-gtk-utils.h>
 #include "sunone-itip-view.h"
 
 #define MEETING_ICON "stock_new-meeting"
